@@ -74,7 +74,7 @@ def run(input_file, query_import, force_all_import):
             new_note["artifact_descriptor"] = result.get_src_artifact()
             new_note["submission_tool"] = "Checkmarx"
             new_note["note_type"] = "LOG"
-            new_note["contents"] = "**Security Issue Found**\n\n"
+            new_note["contents"] = "**Source for Security Issue**\n\n"
             new_note["contents"] += "**Description** - " + result.query_name + "\n"
             new_note["contents"] += "**Severity** - " + result.severity.capitalize()
 
@@ -87,7 +87,9 @@ def run(input_file, query_import, force_all_import):
             new_note["artifact_descriptor"] = result.get_sink_artifact()
             new_note["submission_tool"] = "Checkmarx"
             new_note["note_type"] = "LOG"
-            new_note["contents"] = "**Sink for Security Issue**"
+            new_note["contents"] = "**Sink for Security Issue**" + "\n"
+            new_note["contents"] += "**Description** - " + result.query_name + "\n"
+            new_note["contents"] += "**Severity** - " + result.severity.capitalize()
 
             # Detection and prevention of duplicate notes is handled by the server.
             lcu.loci_api_req(f"/api/projects/{project_id}/notes", method="POST",
